Crate merkle_sdk_transactions

Crate merkle_sdk_transactions 

Structs

Connection
Utility struct to acquire a connection to our exposed transaction stream.
ConnectionBuilder
Builder struct for Connection instances.
Transaction
Wrapper struct for a ethers-rs transaction plus signature.
Transactions
This struct implements a stream of pooled transactions. Performs adaptation logics over the bytes stream received from the websocket.

Enums

ChainId
ChainName
TxnStreamError