Structs
- Connection
- Utility struct to acquire a connection to our exposed transaction stream.
- Connection
Builder - Builder struct for
Connectioninstances. - Transaction
- Wrapper struct for a
ethers-rstransaction plus signature. - Transactions
- This struct implements a stream of pooled transactions. Performs adaptation logics over the bytes stream received from the websocket.